@@ -7,7 +7,7 @@ In addition Django's built in 403 and 404 exceptions are handled.
 import math
 
 from django.http import JsonResponse
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import ngettext
 
@@ -36,7 +36,7 @@ def _get_error_details(data, default_code=None):
             return ReturnDict(ret, serializer=data.serializer)
         return ret
 
-    text = force_text(data)
+    text = force_str(data)
     code = getattr(data, 'code', default_code)
     return ErrorDetail(text, code)
 
@@ -191,7 +191,7 @@ class MethodNotAllowed(APIException):
 
     def __init__(self, method, detail=None, code=None):
         if detail is None:
-            detail = force_text(self.default_detail).format(method=method)
+            detail = force_str(self.default_detail).format(method=method)
         super().__init__(detail, code)
 
 
@@ -212,7 +212,7 @@ class UnsupportedMediaType(APIException):
 
     def __init__(self, media_type, detail=None, code=None):
         if detail is None:
-            detail = force_text(self.default_detail).format(media_type=media_type)
+            detail = force_str(self.default_detail).format(media_type=media_type)
         super().__init__(detail, code)
 
 
@@ -225,14 +225,14 @@ class Throttled(APIException):
 
     def __init__(self, wait=None, detail=None, code=None):
         if detail is None:
-            detail = force_text(self.default_detail)
+            detail = force_str(self.default_detail)
         if wait is not None:
             wait = math.ceil(wait)
             detail = ' '.join((
                 detail,
-                force_text(ngettext(self.extra_detail_singular.format(wait=wait),
-                                    self.extra_detail_plural.format(wait=wait),
-                                    wait))))
+                force_str(ngettext(self.extra_detail_singular.format(wait=wait),
+                                   self.extra_detail_plural.format(wait=wait),
+                                   wait))))
         self.wait = wait
         super().__init__(detail, code)
 
